<header class="masthead mb-auto">
    <div class="inner">
        <a href="/"><h3 class="masthead-brand">go/llama</h3></a>
        <nav class="nav nav-masthead justify-content-center">
            <div class="container">
                <div class="d-flex justify-content-end">
                    <div class="my-2 my-lg-0">
                        <input id="search" class="form-control mr-sm-2" type="search" placeholder="Search"
                               aria-label="Search">
                    </div>
                </div>
            </div>
        </nav>
    </div>
</header>