{% extends 'base.html' %}
{% block content %}
    <div class="container">
        <h3>Could not find go/{{ shorthand }}</h3>
        <h5>Would you like to <a href="/#new={{ shorthand }}">create go/{{ shorthand }}</a></h5>
    </div>
    <div class="container text-center">
        {% if candidates %}
            <p class="text-center">Did you mean:</p>
            {% for candidate in candidates %}
                <div class="row"><a href="{{ candidate.url }}">go/{{ candidate.label }}</a></div>
            {% endfor %}
        {% endif %}
    </div>


{% endblock %}